import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import Send from '@material-ui/icons/Send'

const InputContainer = styled.div`
  width: 100%;
  padding-top: 15px;
  display: grid;
  grid-template-columns: 95% 5%;
`;

const TextInput = styled.input`
  height: 30px;
  border-radius:20px;
  border-width: 1px;
  font-size: 15px;
  padding-left: 10px;
  padding-right: 10px;
  border-color: #848484;
  border-style: solid;
  position: relative;
  top: 50%;
  outline: none;
  transform: translateY(-50%);
  justify-self: stretch;
`;

const SubmitButton = styled.button`
  border: none;
  height: 30px;
  width: 5%;
  position: relative;
  top: 50%;
  transform: translateY(-50%);
  outline: none;
  align-self: start;
`;

export default class MessageInput extends PureComponent {

  render() {
    const
    {
        placeholder,
        onSubmit
    } = this.props;

    return (
      <InputContainer>
        <TextInput placeholder={placeholder} onKeyPress={(e) => {
          if (e.type === 'keypress' && e.key === 'Enter') {
            onSubmit(e);
          }
        }} />
        <SubmitButton onClick={(e) => onSubmit(e)}>
          <Send/>
        </SubmitButton>
      </InputContainer>
    );
  }
}

MessageInput.propTypes = {
  placeholder: PropTypes.string,
  onSubmit: PropTypes.func
};
